#!/bin/sh
# SPDX-License-Identifier: MIT

set -e

export LC_ALL=en_US.UTF-8
export LANG=en_US.UTF-8
export PATH="/usr/bin:/bin:/usr/sbin:/sbin:$PATH"

export INSTALLER_BASE=https://releases.lernstick.ch/apple-silicon-asahiboot
export INSTALLER_DATA=${INSTALLER_BASE}/data/installer_data.json
export REPO_BASE=${INSTALLER_BASE}/data
PKG=installer.tar.gz


TMP="$(mktemp -d)"
#TMP=/tmp/asahi-install

test "$(uname -s)" = "Darwin" && test "$(uname -m)" = "arm64"  || ( echo "Exitting: No Apple Silicon Platform (M1/M2) could be found"; exit -1 )
sysctl -n machdep.cpu.brand_string | grep M3 && ( echo "Exitting: Apple Silicon M3 not yet supported"; exit -1 )

echo
echo "Bootstrapping installer:"

if [ -e "$TMP" ]; then
    mv "$TMP" "$TMP-$(date +%Y%m%d-%H%M%S)"
fi

mkdir -p "$TMP"
cd "$TMP"

echo "  Downloading..."

curl --no-progress-meter -L -O "$INSTALLER_BASE/$PKG"
curl --no-progress-meter -L -O "$INSTALLER_DATA"

echo "  Extracting..."

tar xf "$PKG"

echo "  Initializing..."
echo

if [ "$USER" != "root" ]; then
    echo "The installer needs to run as root."
    echo "Please enter your sudo password if prompted."
    exec caffeinate -dis sudo -E ./install.sh "$@"
else
    exec caffeinate -dis ./install.sh "$@"
fi
